@@ -1,4 +1,4 @@
-// @license magnet:?xt=urn:btih:0b31508aeb0634b347b8270c7bee4d411b5d4109&dn=agpl-3.0.txt AGPL-3.0
+// @license magnet:?xt=urn:btih:0b31508aeb0634b347b8270c7bee4d411b5d4109&dn=agpl-3.0.txt GNU-AGPL-3.0-or-later
 function startQuotes(currId, nextId) {
     const thisQuoteId = [currId];
     const nextQuoteId = [nextId];
@@ -6,6 +6,8 @@ function startQuotes(currId, nextId) {
     const nextButton = elById("next");
     const upvoteButton = elById("upvote");
     const downvoteButton = elById("downvote");
+    // may be missing
+    const reportButton = elById("report");
 
     const keys = (() => {
         let k = new URLSearchParams(params).get("keys");
@@ -54,7 +56,7 @@ function startQuotes(currId, nextId) {
 
     function updateQuoteId(quoteId) {
         shareButton.href = fixHref(`/zitate/share/${quoteId}${params}`);
-        downloadButton.href = fixHref(`/zitate/${quoteId}/image.gif${params}`);
+        downloadButton.href = fixHref(`/zitate/${quoteId}.gif${params}`);
         const [q_id, a_id] = quoteId.split("-", 2);
         quote.href = fixHref(`/zitate/info/z/${q_id}${params}`);
         author.href = fixHref(`/zitate/info/a/${a_id}${params}`);
@@ -66,16 +68,16 @@ function startQuotes(currId, nextId) {
         ratingText.innerText = rating;
         if (["---", "???", "0"].includes(rating)) {
             ratingImageContainer.innerHTML = "";
-        } else {
-            const ratingNum = Number.parseInt(rating);
-            const ratingImg = d.createElement("div")
-            ratingImg.className = "rating-img" + (
-                ratingNum > 0 ? " witzig" : " nicht-witzig"
-            );
-            ratingImageContainer.innerHTML = (
-                ratingImg.outerHTML + " "
-            ).repeat(Math.min(4, Math.abs(ratingNum)));
+            return;
         }
+        const ratingNum = Number.parseInt(rating);
+        const ratingImg = d.createElement("div")
+        ratingImg.className = "rating-img" + (
+            ratingNum > 0 ? " witzig" : " nicht-witzig"
+        );
+        ratingImageContainer.innerHTML = (
+            ratingImg.outerHTML + " "
+        ).repeat(Math.min(4, Math.abs(ratingNum))).trim();
     }
 
     function updateVote(vote) {
@@ -101,6 +103,7 @@ function startQuotes(currId, nextId) {
         if (data["status"]) {
             error(data)
             if (data["status"] in [429, 420])
+                // ratelimited
                 alert(data["reason"]);
         } else if (data && data["id"]) {
             updateQuoteId(data["id"]);
@@ -111,6 +114,16 @@ function startQuotes(currId, nextId) {
             realAuthor.href = fixHref(
                 `/zitate/info/a/${data["real_author_id"]}${params}`
             );
+            if (reportButton) {
+                const reportHrefParams = new URLSearchParams(params);
+                reportHrefParams.set(
+                    "subject", `Das falsche Zitat ${data["id"]} hat ein Problem`
+                );
+                reportHrefParams.set(
+                    "message", `${quote.innerText} ${realAuthor.innerText}`
+                );
+                reportButton.href = fixHref(`/kontakt?${reportHrefParams}`);
+            }
             updateRating(data["rating"]);
             updateVote(Number.parseInt(data["vote"]));
             return true;
@@ -128,11 +141,13 @@ function startQuotes(currId, nextId) {
             if (!handleData(data)) return;
 
             data["stateType"] = "quotes";
+            data["url"] = `/zitate/${data["id"]}${params}`;
             w.history.pushState(
                 data,
                 "Falsche Zitate",
-                `/zitate/${data["id"]}${params}`
+                data["url"]
             )
+            w.lastLocation = data["url"];
         }
     );
 
