@@ -23,6 +23,7 @@ from typing import Any
 
 from tornado.web import HTTPError
 
+from .. import EVENT_REDIS
 from ..utils.request_handler import APIRequestHandler
 from ..utils.utils import ModuleInfo
 from . import (
@@ -33,7 +34,7 @@ from . import (
 )
 
 
-def get_module_info() -> ModuleInfo:
+def get_module_info(*, hidden: bool = True) -> ModuleInfo:
     """Create and return the ModuleInfo for this module."""
     return ModuleInfo(
         handlers=(
@@ -55,14 +56,14 @@ def get_module_info() -> ModuleInfo:
             ),
         ),
         name="Das Zitat des Tages",
-        description="Jeden Tag ein anderes Zitat.",
+        description="Jeden Tag ein anderes Zitat",
         path="/zitat-des-tages",
         keywords=(
             "Zitate",
             "Witzig",
             "Känguru",
         ),
-        hidden=True,
+        hidden=hidden,
     )
 
 
@@ -130,13 +131,13 @@ class QuoteOfTheDayBaseHandler(QuoteReadyCheckHandler):
 
     async def has_been_used(self, wq_id: str) -> None | bool:
         """Check with Redis here."""
-        if not self.redis:
+        if not EVENT_REDIS.is_set():
             return None
         return bool(await self.redis.get(self.get_redis_used_key(wq_id)))
 
     async def set_used(self, wq_id: str) -> None:
         """Set Redis key with used state and TTL here."""
-        if not self.redis:
+        if not EVENT_REDIS.is_set():
             return
         await self.redis.setex(
             self.get_redis_used_key(wq_id),
@@ -150,11 +151,15 @@ class QuoteOfTheDayBaseHandler(QuoteReadyCheckHandler):
         return f"{self.request.protocol}://{self.request.host}"
 
     async def get_quote_by_date(
-        self, wq_date: date
+        self, wq_date: date | str
     ) -> None | QuoteOfTheDayData:
         """Get the quote of the date if one was saved."""
-        if not self.redis:
+        if not EVENT_REDIS.is_set():
             return None
+
+        if isinstance(wq_date, str):
+            wq_date = date(*tuple(int(x) for x in wq_date.split("-")))
+
         wq_id = await self.redis.get(self.get_redis_quote_date_key(wq_date))
         if not wq_id:
             return None
@@ -168,7 +173,7 @@ class QuoteOfTheDayBaseHandler(QuoteReadyCheckHandler):
 
     async def get_quote_of_today(self) -> None | QuoteOfTheDayData:
         """Get the quote for today."""
-        if not self.redis:
+        if not EVENT_REDIS.is_set():
             return None
         today = datetime.now(tz=timezone.utc).date()
         quote_data = await self.get_quote_by_date(today)
@@ -208,74 +213,74 @@ class QuoteOfTheDayRss(QuoteOfTheDayBaseHandler):
         if head:
             return
         today = datetime.now(tz=timezone.utc).date()
+        quotes = (
+            await self.get_quote_of_today(),
+            *[
+                await self.get_quote_by_date(today - timedelta(days=i))
+                for i in range(1, 5)
+            ],
+        )
         await self.render(
             "rss/quote_of_the_day.xml",
-            quotes=tuple(
-                quote
-                for quote in (
-                    [await self.get_quote_of_today()]
-                    + [
-                        (
-                            await self.get_quote_by_date(
-                                today - timedelta(days=i)
-                            )
-                        )
-                        for i in range(1, 5)
-                    ]
-                )
-                if quote
-            ),
+            quotes=tuple(q for q in quotes if q),
         )
 
 
 class QuoteOfTheDayAPI(QuoteOfTheDayBaseHandler, APIRequestHandler):
     """Handler for the JSON API that returns the quote of the day."""
 
-    async def get(self, date_str: None | str = None) -> None:
+    async def get(
+        self,
+        date_str: None | str = None,
+        *,
+        head: bool = False,  # pylint: disable=unused-argument
+    ) -> None:
         """Handle GET requests."""
-        if date_str:
-            year, month, day = tuple(int(x) for x in date_str.split("-"))
-            quote_data = await self.get_quote_by_date(
-                date(year=year, month=month, day=day)
-            )
-        else:
-            quote_data = await self.get_quote_of_today()
+        quote_data = await (
+            self.get_quote_by_date(date_str)
+            if date_str
+            else self.get_quote_of_today()
+        )
 
-        if quote_data:
-            if self.request.path.endswith("/full/"):
-                return await self.finish(quote_data.to_json())
-            wrong_quote = quote_data.wrong_quote
-            return await self.finish(
-                {
-                    "date": quote_data.date.isoformat(),
-                    "url": quote_data.get_quote_url(),
-                    "id": wrong_quote.get_id_as_str(),
-                    "quote": str(wrong_quote.quote),
-                    "author": str(wrong_quote.author),
-                    "rating": wrong_quote.rating,
-                }
-            )
-        raise HTTPError(404)
+        if not quote_data:
+            raise HTTPError(404)
+
+        if self.request.path.endswith("/full"):
+            return await self.finish(quote_data.to_json())
+
+        wrong_quote = quote_data.wrong_quote
+        await self.finish_dict(
+            date=quote_data.date.isoformat(),
+            url=quote_data.get_quote_url(),
+            id=wrong_quote.get_id_as_str(),
+            quote=str(wrong_quote.quote),
+            author=str(wrong_quote.author),
+            rating=wrong_quote.rating,
+        )
 
 
 class QuoteOfTheDayRedirect(QuoteOfTheDayBaseHandler):
     """Redirect to the quote of the day."""
 
-    async def get(self, date_str: None | str = None) -> None:
+    async def get(
+        self,
+        date_str: None | str = None,
+        *,
+        head: bool = False,  # pylint: disable=unused-argument
+    ) -> None:
         """Handle GET requests."""
-        if date_str:
-            year, month, day = tuple(int(x) for x in date_str.split("-"))
-            wrong_quote = await self.get_quote_by_date(
-                date(year=year, month=month, day=day)
-            )
-        else:
-            wrong_quote = await self.get_quote_of_today()
+        wrong_quote_data = await (
+            self.get_quote_by_date(date_str)
+            if date_str
+            else self.get_quote_of_today()
+        )
 
-        if wrong_quote:
-            return self.redirect(
-                self.fix_url(
-                    wrong_quote.get_quote_url(), as_json=self.get_as_json()
-                ),
-                False,
-            )
-        raise HTTPError(404)
+        if not wrong_quote_data:
+            raise HTTPError(404)
+
+        self.redirect(
+            self.fix_url(
+                wrong_quote_data.get_quote_url(), as_json=self.get_as_json()
+            ),
+            False,
+        )
