@@ -22,14 +22,17 @@ from __future__ import annotations
 import asyncio
 import logging
 import random
+import re
 from asyncio import Task
-from collections.abc import Awaitable
-from typing import Any, Literal
+from collections.abc import Coroutine, Generator
+from typing import Any, Literal, cast
 
 from tornado.web import HTTPError, RedirectHandler
 
+from .. import EVENT_REDIS
+from ..main import IGNORED_MODULES
 from ..utils.request_handler import APIRequestHandler
-from ..utils.utils import ModuleInfo, hash_ip, str_to_bool
+from ..utils.utils import ModuleInfo, hash_ip
 from . import (
     WRONG_QUOTES_CACHE,
     QuoteReadyCheckHandler,
@@ -40,7 +43,10 @@ from . import (
     get_wrong_quote,
     get_wrong_quotes,
 )
+from .create import get_module_info as get_create_mi
+from .quote_generator import get_module_info as get_generator_mi
 from .quote_of_the_day import QuoteOfTheDayBaseHandler
+from .quote_of_the_day import get_module_info as get_qod_mi
 from .quotes_image import QuoteAsImage
 from .share_page import ShareQuote
 
@@ -96,6 +102,11 @@ def get_module_info() -> ModuleInfo:
         description="Witzige, aber falsch zugeordnete Zitate",
         path="/zitate",
         aliases=("/z",),
+        sub_pages=(
+            get_create_mi(hidden=False),
+            get_generator_mi(hidden=False),
+            get_qod_mi(hidden="quotes.quote_of_the_day" in IGNORED_MODULES),
+        ),
         keywords=(
             "falsch",
             "zugeordnet",
@@ -129,8 +140,8 @@ def vote_to_int(vote: str) -> Literal[-1, 0, 1]:
 
 SMART_RATING_FILTERS = (
     *(("n",) * 1),
-    *(("all",) * 3),
-    *(("w",) * 4),
+    *(("all",) * 5),
+    *(("w",) * 5),
 )
 
 
@@ -142,7 +153,9 @@ class QuoteBaseHandler(QuoteReadyCheckHandler):
     def __init__(self, *args, **kwargs):  # type: ignore
         """Initialize the base request handler."""
         super().__init__(*args, **kwargs)
-        self.awaitables: list[Awaitable[Any]] = []
+        self.awaitables: list[
+            Generator[Any, None, Any] | Coroutine[Any, Any, Any]
+        ] = []
 
     def rating_filter(
         self,
@@ -163,9 +176,7 @@ class QuoteBaseHandler(QuoteReadyCheckHandler):
 
     def get_show_rating(self) -> bool:
         """Return whether the user wants to see the rating."""
-        return str_to_bool(
-            self.get_argument("show-rating", default=None), default=False
-        )
+        return self.get_bool_argument("show-rating", default=False)
 
     def get_next_url(self) -> str:
         """Get the URL of the next quote."""
@@ -179,36 +190,34 @@ class QuoteBaseHandler(QuoteReadyCheckHandler):
             **{"show-rating": self.get_show_rating() or None},  # type: ignore[arg-type]
         )
 
-    def get_next_id(  # noqa: C901  # pylint: disable=too-complex
-        self, rating_filter: None | str = None
-    ) -> tuple[int, int]:
+    def get_next_id(self, rating_filter: None | str = None) -> tuple[int, int]:
         """Get the id of the next quote."""
         if rating_filter is None:
             rating_filter = self.rating_filter()
+
         if rating_filter == "smart":
             rating_filter = random.choice(SMART_RATING_FILTERS)
 
-        if rating_filter == "unrated":
-            # get a random quote, but filter out already rated quotes
-            # pylint: disable=while-used
-            while (ids := get_random_id()) in WRONG_QUOTES_CACHE:
-                if WRONG_QUOTES_CACHE[ids].id == -1:
-                    # Check for wrong quotes, that are unrated but in
-                    # the cache. They don't have a real wrong_quotes_id
-                    return ids
-            return ids
-
-        if rating_filter == "all":
-            return get_random_id()
-
-        if rating_filter == "w":
-            wrong_quotes = get_wrong_quotes(lambda wq: wq.rating > 0)
-        elif rating_filter == "n":
-            wrong_quotes = get_wrong_quotes(lambda wq: wq.rating < 0)
-        elif rating_filter == "rated":
-            wrong_quotes = get_wrong_quotes()
-        else:
-            wrong_quotes = None
+        match rating_filter:
+            case "unrated":
+                # get a random quote, but filter out already rated quotes
+                # pylint: disable=while-used
+                while (ids := get_random_id()) in WRONG_QUOTES_CACHE:
+                    if WRONG_QUOTES_CACHE[ids].id == -1:
+                        # Check for wrong quotes that are unrated but in
+                        # the cache. They don't have a real wrong_quotes_id.
+                        return ids
+                return ids
+            case "all":
+                return get_random_id()
+            case "w":
+                wrong_quotes = get_wrong_quotes(lambda wq: wq.rating > 0)
+            case "n":
+                wrong_quotes = get_wrong_quotes(lambda wq: wq.rating < 0)
+            case "rated":
+                wrong_quotes = get_wrong_quotes()
+            case _:
+                wrong_quotes = tuple()
 
         if not wrong_quotes:
             # invalid rating filter or no wrong quotes with that filter
@@ -243,14 +252,21 @@ class QuoteMainPage(QuoteBaseHandler, QuoteOfTheDayBaseHandler):
         """Render the main quote page, with a few links."""
         if head:
             return
+        quote = cast(str, self.get_argument("quote", ""))
+        author = cast(str, self.get_argument("author", ""))
+        if (quote or author) and re.fullmatch(r"^[0-9]+$", quote + author):
+            self.redirect(self.fix_url(f"/zitate/{quote}-{author}"))
+            return
+
         await self.render(
             "pages/quotes/quotes_main_page.html",
             funny_quote_url=self.id_to_url(
-                *get_wrong_quotes(
-                    lambda wq: wq.rating > 0,
-                    shuffle=True,
-                )[0].get_id(),
-                "w",
+                *(
+                    get_wrong_quotes(lambda wq: wq.rating > 0, shuffle=True)[
+                        0
+                    ].get_id()
+                ),
+                rating_param="w",
             ),
             random_quote_url=self.id_to_url(*self.get_next_id()),
             quote_of_the_day=await self.get_quote_of_today(),
@@ -276,8 +292,6 @@ class QuoteMainPage(QuoteBaseHandler, QuoteOfTheDayBaseHandler):
 class QuoteRedirectAPI(QuoteBaseHandler, APIRequestHandler):
     """Redirect to the api for a random quote."""
 
-    IS_NOT_HTML = True
-
     async def get(  # pylint: disable=unused-argument
         self, suffix: str = "", *, head: bool = False
     ) -> None:
@@ -285,7 +299,7 @@ class QuoteRedirectAPI(QuoteBaseHandler, APIRequestHandler):
         quote_id, author_id = self.get_next_id(rating_filter="w")
         return self.redirect(
             self.fix_url(
-                f"/api/zitate/{quote_id}-{author_id}/{suffix}",
+                f"/api/zitate/{quote_id}-{author_id}{suffix}",
                 as_json=self.get_as_json(),
             )
         )
@@ -418,7 +432,7 @@ class QuoteById(QuoteBaseHandler):
     ) -> None:
         """Save the new vote in Redis."""
         result = None
-        if self.redis:
+        if EVENT_REDIS.is_set():
             result = await self.redis.setex(
                 self.get_redis_votes_key(quote_id, author_id),
                 60 * 60 * 24 * 90,  # time to live in seconds (3 months)
@@ -446,7 +460,7 @@ class QuoteById(QuoteBaseHandler):
         Use the quote_id and author_id to query the vote.
         Return None if nothing is saved.
         """
-        if not self.redis:
+        if not EVENT_REDIS.is_set():
             logger.warning("No Redis connection")
             return 0
         result = await self.redis.get(
@@ -475,22 +489,18 @@ class QuoteAPIHandler(QuoteById, APIRequestHandler):
         """Return the relevant data for the quotes page as JSON."""
         next_q, next_a = self.get_next_id()
         if self.request.path.endswith("/full"):
-            return await self.finish(
-                {
-                    "wrong_quote": wrong_quote.to_json(),
-                    "next": f"{next_q}-{next_a}",
-                    "vote": vote,
-                }
+            return await self.finish_dict(
+                wrong_quote=wrong_quote.to_json(),
+                next=f"{next_q}-{next_a}",
+                vote=vote,
             )
-        return await self.finish(
-            {
-                "id": wrong_quote.get_id_as_str(),
-                "quote": str(wrong_quote.quote),
-                "author": str(wrong_quote.author),
-                "real_author": str(wrong_quote.quote.author),
-                "real_author_id": wrong_quote.quote.author.id,
-                "rating": await self.get_rating_str(wrong_quote),
-                "vote": vote,
-                "next": f"{next_q}-{next_a}",
-            }
+        return await self.finish_dict(
+            id=wrong_quote.get_id_as_str(),
+            quote=str(wrong_quote.quote),
+            author=str(wrong_quote.author),
+            real_author=str(wrong_quote.quote.author),
+            real_author_id=wrong_quote.quote.author.id,
+            rating=await self.get_rating_str(wrong_quote),
+            vote=vote,
+            next=f"{next_q}-{next_a}",
         )
