@@ -52,12 +52,10 @@ HOST_NAME_FONT = ImageFont.truetype(
 
 def load_png(file_name: str) -> Image.Image:
     """Load a PNG image into memory."""
-    image = Image.open(
+    with Image.open(
         os.path.join(DIR, "files", f"{file_name}.png"), formats=("PNG",)
-    )
-    image_copy = image.copy()
-    image.close()
-    return image_copy
+    ) as image:
+        return image.copy()
 
 
 BACKGROUND_IMAGE = load_png("bg")
@@ -316,10 +314,7 @@ class QuoteAsImage(QuoteReadyCheckHandler):
 
         source: None | str = (
             None
-            if str_to_bool(
-                str(self.get_argument("no_source", default="False")),
-                default=False,
-            )
+            if self.get_bool_argument("no_source", default=False)
             else f"{self.request.host_name}/z/{wrong_quote.get_id_as_str(True)}"
         )
 
