@@ -79,51 +79,43 @@ class SwappedWords(HTMLRequestHandler):
     """The request handler for the swapped words page."""
 
     def handle_text(
-        self, text: str, config_str: None | str, reset: str
+        self, text: str, config_str: None | str, use_default_config: str
     ) -> None:
         """Use the text to display the HTML page."""
         check_text_too_long(text)
 
-        try:
-            if config_str is None:
-                _c = self.get_cookie(
-                    name="swapped-words-config",
-                    default=None,
-                )
-                if _c is not None:
-                    # decode the base64 text
-                    config_str = str(
-                        base64.b64decode(_c.encode("utf-8")), "utf-8"
-                    )
-            else:
-                # save the config in a cookie
-                self.set_cookie(
-                    name="swapped-words-config",
-                    value=str(
-                        # encode the config as base64
-                        base64.b64encode(config_str.encode("utf-8")),
-                        "utf-8",
-                    ),
-                    expires_days=1000,
-                    path=self.request.path,
-                    SameSite="Strict",
+        if config_str is None:
+            cookie = self.get_cookie(
+                name="swapped-words-config",
+                default=None,
+            )
+            if cookie is not None:
+                # decode the base64 text
+                config_str = str(
+                    base64.b64decode(cookie.encode("utf-8")), "utf-8"
                 )
+        else:
+            # save the config in a cookie
+            self.set_cookie(
+                name="swapped-words-config",
+                value=str(
+                    # encode the config as base64
+                    base64.b64encode(config_str.encode("utf-8")),
+                    "utf-8",
+                ),
+                expires_days=1000,
+                path=self.request.path,
+                SameSite="Strict",
+            )
 
+        try:
             sw_config = (
                 DEFAULT_CONFIG
-                if config_str is None or str_to_bool(reset)
+                if config_str is None or str_to_bool(use_default_config)
                 else SwappedWordsConfig(config_str)
             )
-
-            self.render(
-                "pages/swapped_words.html",
-                text=text,
-                output=sw_config.swap_words(text),
-                config=sw_config.to_config_str(),
-                MAX_CHAR_COUNT=MAX_CHAR_COUNT,
-                error_msg=None,
-            )
         except InvalidConfigError as exc:
+            self.set_status(400)
             self.render(
                 "pages/swapped_words.html",
                 text=text,
@@ -132,6 +124,15 @@ class SwappedWords(HTMLRequestHandler):
                 MAX_CHAR_COUNT=MAX_CHAR_COUNT,
                 error_msg=str(exc),
             )
+        else:  # everything went well
+            self.render(
+                "pages/swapped_words.html",
+                text=text,
+                output=sw_config.swap_words(text),
+                config=sw_config.to_config_str(),
+                MAX_CHAR_COUNT=MAX_CHAR_COUNT,
+                error_msg=None,
+            )
 
     def get(
         self, *, head: bool = False  # pylint: disable=unused-argument
@@ -161,14 +162,12 @@ class SwappedWordsAPI(APIRequestHandler):
         self, *, head: bool = False  # pylint: disable=unused-argument
     ) -> None:
         """Handle GET requests to the swapped words API."""
-        text = self.get_argument("text", default=None, strip=True) or ""
+        text = self.get_argument("text", default=None) or ""
 
         check_text_too_long(text)
 
-        config_str = self.get_argument("config", default=None, strip=True)
-        return_config = str(
-            self.get_argument("return_config", default="nope", strip=True)
-        )
+        config_str = self.get_argument("config", default=None)
+        return_config = str(self.get_argument("return_config", default="nope"))
         try:
             sw_config = (
                 DEFAULT_CONFIG
@@ -178,34 +177,30 @@ class SwappedWordsAPI(APIRequestHandler):
 
             if str_to_bool(return_config, False):
 
-                minify_config = self.get_argument(
-                    "minify_config", default="sure", strip=True
+                minify_config = str_to_bool(
+                    self.get_argument(
+                        "minify_config", default="sure", strip=True
+                    ),
+                    True,
                 )
-                return await self.finish(
-                    {
-                        "text": text,
-                        "return_config": True,
-                        "config": sw_config.to_config_str(
-                            minified=str_to_bool(minify_config, True)
-                        ),
-                        "replaced_text": sw_config.swap_words(text),
-                    }
+                return await self.finish_dict(
+                    text=text,
+                    return_config=True,
+                    minify_config=minify_config,
+                    config=sw_config.to_config_str(minify_config),
+                    replaced_text=sw_config.swap_words(text),
                 )
-            return await self.finish(
-                {
-                    "text": text,
-                    "return_config": False,
-                    "replaced_text": sw_config.swap_words(text),
-                }
+            return await self.finish_dict(
+                text=text,
+                return_config=False,
+                replaced_text=sw_config.swap_words(text),
             )
         except InvalidConfigError as exc:
             self.set_status(400)
-            return await self.finish(
-                {
-                    "error": exc.reason,
-                    "line": exc.line,
-                    "line_num": exc.line_num,
-                }
+            return await self.finish_dict(
+                error=exc.reason,
+                line=exc.line,
+                line_num=exc.line_num,
             )
 
     async def post(self) -> None:
