@@ -21,7 +21,6 @@ from __future__ import annotations
 
 import inspect
 import logging
-import os
 import random
 import re
 import sys
@@ -43,14 +42,14 @@ from blake3 import blake3  # type: ignore
 from bs4 import BeautifulSoup
 from dateutil.easter import easter
 from elasticsearch import AsyncElasticsearch
+from elasticsearch.exceptions import ElasticsearchException
 from Levenshtein import distance  # type: ignore
-from redis.asyncio import Redis  # type: ignore
+from redis.asyncio import Redis
+from sympy.ntheory import isprime
 from tornado import web
-from tornado.httpclient import AsyncHTTPClient
 from tornado.web import HTTPError, MissingArgumentError, RequestHandler
 
-from .. import DIR as ROOT_DIR
-from .. import REPO_URL
+from .. import EVENT_ELASTICSEARCH, EVENT_REDIS, REPO_URL
 from .static_file_handling import fix_static_url
 from .utils import (
     THEMES,
@@ -60,7 +59,6 @@ from .utils import (
     anonymize_ip,
     bool_to_str,
     geoip,
-    name_to_id,
     str_to_bool,
 )
 
@@ -79,11 +77,6 @@ def get_module_info() -> ModuleInfo:
                 {},
             ),
             (r"/([1-5][0-9]{2}).html?", ErrorPage, {}),
-            (
-                r"/@elastic/apm-rum@(.+)/dist/bundles"
-                r"/elastic-apm-rum.umd(\.min|).js(\.map|)",
-                ElasticRUM,
-            ),
         ),
         hidden=True,
     )
@@ -134,33 +127,13 @@ class BaseRequestHandler(RequestHandler):
                 self.request.path
             ).description
 
-    def redirect(
-        self, url: str, permanent: bool = False, status: None | int = None
-    ) -> None:
-        """Send a redirect to the given (optionally relative) URL.
-
-        If the ``status`` argument is specified, that value is used as the
-        HTTP status code; otherwise either 308 (permanent) or 307
-        (temporary) is chosen based on the ``permanent`` argument.
-        The default is 307 (temporary).
-        """
-        if self._headers_written:
-            raise Exception("Cannot redirect after headers have been written")
-        if status is None:
-            status = 308 if permanent else 307
-        else:
-            assert isinstance(status, int) and 300 <= status <= 399
-        self.set_status(status)
-        self.set_header("Location", url)
-        self.finish()
-
     def data_received(self, chunk: Any) -> None:
         """Do nothing."""
 
     @property
-    def redis(self) -> None | Redis:
+    def redis(self) -> Redis:  # type: ignore[type-arg]
         """Get the Redis client from the settings."""
-        return self.settings.get("REDIS")
+        return cast(Redis, self.settings.get("REDIS"))  # type: ignore[type-arg]
 
     @property
     def redis_prefix(self) -> str:
@@ -168,9 +141,9 @@ class BaseRequestHandler(RequestHandler):
         return self.settings.get("REDIS_PREFIX", "")
 
     @property
-    def elasticsearch(self) -> None | AsyncElasticsearch:
+    def elasticsearch(self) -> AsyncElasticsearch:
         """Get the Elasticsearch client from the settings."""
-        return self.settings.get("ELASTICSEARCH")
+        return cast(AsyncElasticsearch, self.settings.get("ELASTICSEARCH"))
 
     @property
     def elasticsearch_prefix(self) -> str:
@@ -185,15 +158,20 @@ class BaseRequestHandler(RequestHandler):
     def set_default_headers(self) -> None:
         """Set default headers."""
         # see: dev.mozilla.org/docs/Web/HTTP/Headers
+        self.set_header("Access-Control-Max-Age", "7200")
+        self.set_header("Access-Control-Allow-Origin", "*")
+        self.set_header("Access-Control-Allow-Headers", "*")
+        self.set_header(
+            "Access-Control-Allow-Methods",
+            ", ".join(self.get_allowed_methods()),
+        )
         # Opt out of all FLoC cohort calculation.
         self.set_header("Permissions-Policy", "interest-cohort=()")
-        # send only origin in Referer header if request is cross-origin
-        self.set_header("Referrer-Policy", "origin-when-cross-origin")
+        # don't send the Referer header for cross-origin requests
+        self.set_header("Referrer-Policy", "same-origin")
         if self.settings.get("HSTS"):
             # dev.mozilla.org/docs/Web/HTTP/Headers/Strict-Transport-Security
-            self.set_header(
-                "Strict-Transport-Security", "max-age=31536000; preload"
-            )
+            self.set_header("Strict-Transport-Security", "max-age=63072000")
         if (
             _oa := self.settings.get("ONION_ADDRESS")
         ) and not self.request.host_name.endswith(".onion"):
@@ -205,7 +183,7 @@ class BaseRequestHandler(RequestHandler):
                 + (f"?{self.request.query}" if self.request.query else ""),
             )
         if self.settings.get("debug"):
-            self.set_header("X-Dev-Mode", bool_to_str(True))
+            self.set_header("X-Debug", bool_to_str(True))
             for permission in Permissions:
                 if permission.name:
                     self.set_header(
@@ -213,6 +191,31 @@ class BaseRequestHandler(RequestHandler):
                         bool_to_str(self.is_authorized(permission)),
                     )
 
+    def set_cookie(  # pylint: disable=too-many-arguments
+        self,
+        name: str,
+        value: str | bytes,
+        domain: None | str = None,
+        expires: None | float | tuple[int, ...] | datetime = None,
+        path: str = "/",
+        expires_days: None | float = 365,  # changed
+        **kwargs: Any,
+    ) -> None:
+        """Override the set_cookie method to set expires days."""
+        if "samesite" not in kwargs:
+            # default for same site should be strict
+            kwargs["samesite"] = "Strict"
+
+        super().set_cookie(
+            name,
+            value,
+            domain,
+            expires,
+            path,
+            expires_days,
+            **kwargs,
+        )
+
     async def prepare(  # pylint: disable=invalid-overridden-method
         self,
     ) -> None:
@@ -225,8 +228,9 @@ class BaseRequestHandler(RequestHandler):
             if self.redirect_to_canonical_domain():
                 return
 
-            if (days := random.randint(0, 31337)) in {69, 420, 1337, 31337}:
-                self.set_cookie("c", "s", expires_days=days / 24, path="/")
+            if not self.settings.get("TESTING"):
+                if (days := random.randint(0, 31337)) in {69, 420, 1337, 31337}:
+                    self.set_cookie("c", "s", expires_days=days / 24, path="/")
 
         if self.request.method != "OPTIONS":
 
@@ -302,13 +306,13 @@ class BaseRequestHandler(RequestHandler):
                 self, f"RATELIMIT_{method}_PERIOD", 60  # period in seconds
             )
             tokens = 1 if self.request.method != "HEAD" else 0
-        if self.redis is None:
+        if not EVENT_REDIS.is_set():
             raise HTTPError(
                 503,
                 "Ratelimits are enabled, but Redis is not available. "
                 "This can happen shortly after starting the website.",
             )
-        result = await self.redis.execute_command(
+        result = await self.redis.execute_command(  # type: ignore[no-untyped-call]
             "CL.THROTTLE",
             key,
             max_burst,
@@ -452,7 +456,6 @@ class BaseRequestHandler(RequestHandler):
     def fix_url(  # noqa: C901
         self,
         url: None | str | SplitResult = None,
-        this_url: None | str = None,
         new_path: None | str = None,
         **query_args: None | str | bool | float,
     ) -> str:
@@ -467,15 +470,8 @@ class BaseRequestHandler(RequestHandler):
         if isinstance(url, str):
             url = urlsplit(url)
         if url.netloc and url.netloc.lower() != self.request.host.lower():
-            this_url = this_url or self.request.full_url()
-            if urlsplit(this_url).path == "/redirect":
-                # do not create long urls
-                this_url = self.get_argument("from", default="/") or "/"
-            # URL is to other website:
-            url = urlsplit(
-                f"/redirect?to={quote(url.geturl())}&from={quote(this_url)}"
-            )
-        path = new_path or url.path  # the path of the url
+            url = urlsplit(f"/redirect?to={quote(url.geturl())}")
+        path = url.path if new_path is None else new_path  # the path of the url
         # don't add as_json=nope to url if as_json is False
         # pylint: disable=compare-to-zero  # if None it shouldn't be deleted
         if "as_json" in query_args and query_args["as_json"] is False:
@@ -508,7 +504,7 @@ class BaseRequestHandler(RequestHandler):
 
     def get_as_json(self) -> bool:
         """Get the value of the as_json query parameter."""
-        return str_to_bool(self.get_argument("as_json", default="nope"), False)
+        return self.get_bool_argument("as_json", default=False)
 
     def get_no_3rd_party_default(self) -> bool:
         """Get the default value for the no_3rd_party param."""
@@ -524,26 +520,21 @@ class BaseRequestHandler(RequestHandler):
 
     def get_no_3rd_party(self) -> bool:
         """Return the no_3rd_party query argument as boolean."""
-        saved = self.get_saved_no_3rd_party()
-        no_3rd_party = self.get_argument("no_3rd_party", default=None)
-        if no_3rd_party is None:
-            return saved
-        return str_to_bool(no_3rd_party, saved)
+        return self.get_bool_argument(
+            "no_3rd_party", default=self.get_saved_no_3rd_party()
+        )
 
     def get_saved_dynload(self) -> bool:
         """Get the saved value for dynload."""
+        default = False  # TODO: change this
         dynload = self.get_cookie("dynload")
         if dynload is None:
-            return False
-        return str_to_bool(dynload, False)
+            return default
+        return str_to_bool(dynload, default)
 
     def get_dynload(self) -> bool:
         """Return the dynload query argument as boolean."""
-        saved = self.get_saved_dynload()
-        dynload = self.get_argument("dynload", default=None)
-        if dynload is None:
-            return saved
-        return str_to_bool(dynload, saved)
+        return self.get_bool_argument("dynload", self.get_saved_dynload())
 
     def get_saved_theme(self) -> str:
         """Get the theme saved in the cookie."""
@@ -573,15 +564,21 @@ class BaseRequestHandler(RequestHandler):
             tuple(theme for theme in THEMES if theme not in ignore_themes)
         )
 
-    def get_contact_address(self) -> None | str:
-        """Get the contact address from the settings."""
-        address: None | str = self.settings.get("CONTACT_ADDRESS")
-        if not address:
-            return None
-        if not address.startswith("@"):
-            return address
-        # if address starts with @ it's a catch-all address
-        return name_to_id(self.request.path) + "_contact" + address
+    def get_bool_argument(
+        self,
+        name: str,
+        default: None | bool = None,
+    ) -> bool:
+        """Get an argument parsed as boolean."""
+        if default is not None:
+            return str_to_bool(
+                self.get_argument(name, bool_to_str(default)) or "", default
+            )
+        value = str(self.get_argument(name))
+        try:
+            return str_to_bool(value)
+        except ValueError as err:
+            raise HTTPError(400, f"{value} is not a Boolean.") from err
 
     def get_argument(  # type: ignore[override]
         self,
@@ -636,14 +633,25 @@ class BaseRequestHandler(RequestHandler):
         """Get GeoIP information."""
         if not ip:
             ip = str(self.request.remote_ip)
+        if not EVENT_ELASTICSEARCH.is_set():
+            return geoip(ip, database)
         return geoip(ip, database, self.elasticsearch)
 
     async def get_time(self) -> datetime:
         """Get the start time of the request in the user's timezone."""
         tz: tzinfo = timezone.utc  # pylint: disable=invalid-name
-        geoip = await self.geoip()  # pylint: disable=redefined-outer-name
-        if geoip and "timezone" in geoip:
-            tz = ZoneInfo(geoip["timezone"])  # pylint: disable=invalid-name
+        try:
+            geoip = await self.geoip()  # pylint: disable=redefined-outer-name
+        except ElasticsearchException as exc:
+            logger.exception(exc)
+            apm: None | elasticapm.Client = self.settings.get(
+                "ELASTIC_APM_CLIENT"
+            )
+            if apm:
+                apm.capture_exception()
+        else:
+            if geoip and "timezone" in geoip:
+                tz = ZoneInfo(geoip["timezone"])  # pylint: disable=invalid-name
         return datetime.fromtimestamp(
             self.request._start_time, tz=tz  # pylint: disable=protected-access
         )
@@ -696,50 +704,45 @@ class HTMLRequestHandler(BaseRequestHandler):
         They are mostly needed by most of the pages (like title,
         description and no_3rd_party).
         """
-        # pylint: disable=invalid-name
         namespace = super().get_template_namespace()
         namespace.update(
-            {
-                "ansi2html": Ansi2HTMLConverter(inline=True, scheme="xterm"),
-                "title": self.title,
-                "short_title": self.short_title,
-                "description": self.description,
-                "keywords": (
-                    "Asoziales Netzwerk, Känguru-Chroniken"
-                    + (
-                        ""
-                        if self.module_info is None
-                        else ", "
-                        + self.module_info.get_keywords_as_str(
-                            self.request.path
-                        )
-                    )
-                ),
-                "no_3rd_party": self.get_no_3rd_party(),
-                "lang": "de",  # TODO: add language support
-                "form_appendix": self.get_form_appendix(),
-                "fix_url": self.fix_url,
-                "fix_static": lambda url: self.fix_url(fix_static_url(url)),
-                "REPO_URL": REPO_URL,
-                "theme": self.get_display_theme(),
-                "contact_address": self.get_contact_address(),
-                "elastic_rum_js_url": self.ELASTIC_RUM_JS_URL,
-                "canonical_url": self.fix_url(
-                    self.request.full_url().upper()
-                    if self.request.path.upper().startswith("/LOLWUT")
-                    else self.request.full_url().lower()
-                ).split("?")[0],
-                "settings": self.settings,
-                "c": self.now.date() == date(self.now.year, 4, 1)
-                if (c := self.get_cookie("c", None)) is None
-                else str_to_bool(c, False),
-                "🥚": timedelta()
-                <= self.now.date() - easter(self.now.year)
-                < timedelta(days=2),
-                "dynload": self.get_dynload(),
-                "as_json": self.get_as_json(),
-                "now": self.now,
-            }
+            ansi2html=Ansi2HTMLConverter(inline=True, scheme="xterm"),
+            title=self.title,
+            short_title=self.short_title,
+            description=self.description,
+            keywords="Asoziales Netzwerk, Känguru-Chroniken"
+            + (
+                f", {self.module_info.get_keywords_as_str(self.request.path)}"
+                if self.module_info
+                else ""
+            ),
+            no_3rd_party=self.get_no_3rd_party(),
+            lang="de",  # TODO: add language support
+            form_appendix=self.get_form_appendix(),
+            fix_url=self.fix_url,
+            fix_static=lambda url: self.fix_url(fix_static_url(url)),
+            REPO_URL=REPO_URL,
+            theme=self.get_display_theme(),
+            elastic_rum_js_url=self.ELASTIC_RUM_JS_URL,
+            canonical_url=self.fix_url(
+                self.request.full_url().upper()
+                if self.request.path.upper().startswith("/LOLWUT")
+                else self.request.full_url().lower()
+            ).split("?")[0],
+            settings=self.settings,
+            c=self.settings.get("TESTING")
+            or self.now.date() == date(self.now.year, 4, 1)
+            or str_to_bool(self.get_cookie("c", "f") or "f", False),
+            dynload=self.get_dynload(),
+            as_json=self.get_as_json(),
+            now=self.now,
+        )
+        namespace["🥚"] = (
+            self.settings.get("TESTING")
+            or timedelta()
+            <= self.now.date() - easter(self.now.year)
+            < timedelta(days=2)
+            or isprime(self.now.microsecond)  # type: ignore[no-untyped-call]
         )
         return namespace
 
@@ -761,55 +764,41 @@ class HTMLRequestHandler(BaseRequestHandler):
         ):
             return super().finish(chunk)
         self.set_header("Content-Type", "application/json; charset=UTF-8")
-        self.set_header("Access-Control-Allow-Origin", "*")
-        self.set_header("Access-Control-Allow-Headers", "*")
-        self.set_header("Access-Control-Allow-Methods", "OPTIONS, HEAD, GET")
         soup = BeautifulSoup(
             chunk.decode("utf-8") if isinstance(chunk, bytes) else chunk,
             features="lxml",
         )
-        return super().finish(
-            {
-                "url": self.fix_url(  # request url without as_json param
-                    self.request.full_url(), as_json=None
-                ),
-                "title": self.title,
-                "short_title": self.short_title
-                if self.title != self.short_title
-                else None,
-                "body": "".join(
-                    str(_el)
-                    for _el in soup.find_all(name="main", id="body")[0].contents
-                ).strip(),
-                "scripts": [
-                    {
-                        "src": _s.get("src"),
-                        "script": _s.string,
-                        "onload": _s.get("onload"),
-                    }
-                    for _s in soup.find_all("script")
-                    # if "on-every-page" not in _s.attrs # (curr not used)
-                ]
-                if soup.head
-                else [],
-                "stylesheets": (
-                    [
-                        str(_s.get("href")).strip()
-                        for _s in soup.find_all("link", rel="stylesheet")
-                        # if "on-every-page" not in _s.attrs # (curr not used)
-                    ]
-                )
-                if soup.head
-                else [],
-                "css": "\n".join(
-                    str(_s.string or "")
-                    for _s in soup.find_all("style")
-                    # if "on-every-page" not in _s.attrs # (curr not used)
-                ).strip()
-                if soup.head
-                else "",
-            }
+        dictionary: dict[str, Any] = dict(
+            url=self.fix_url(as_json=None),  # request url without as_json param
+            title=self.title,
+            short_title=self.short_title
+            if self.title != self.short_title
+            else None,
+            body="".join(
+                str(_el)
+                for _el in soup.find_all(name="main", id="body")[0].contents
+            ).strip(),
+            scripts=[
+                {
+                    "src": _s.get("src"),
+                    "script": _s.string,
+                    "onload": _s.get("onload"),
+                }
+                for _s in soup.find_all("script")
+            ]
+            if soup.head
+            else [],
+            stylesheets=[
+                str(_s.get("href")).strip()
+                for _s in soup.find_all("link", rel="stylesheet")
+            ]
+            if soup.head
+            else [],
+            css="\n".join(str(_s.string or "") for _s in soup.find_all("style"))
+            if soup.head
+            else "",
         )
+        return super().finish(dictionary)
 
 
 class APIRequestHandler(BaseRequestHandler):
@@ -819,26 +808,22 @@ class APIRequestHandler(BaseRequestHandler):
     It overrides the write error method to return errors as JSON.
     """
 
+    IS_NOT_HTML = True
+
     def set_default_headers(self) -> None:
         """Set important default headers for the API request handlers."""
         super().set_default_headers()
-        # see header docs at: dev.mozilla.org/docs/Web/HTTP/Headers
-        self.set_header("Access-Control-Max-Age", "7200")
         self.set_header("Content-Type", "application/json; charset=UTF-8")
-        self.set_header("Access-Control-Allow-Origin", "*")
-        self.set_header("Access-Control-Allow-Headers", "*")
-        self.set_header(
-            "Access-Control-Allow-Methods",
-            ", ".join(self.get_allowed_methods()),
-        )
+
+    def finish_dict(self, **kwargs: Any) -> Future[None]:
+        """Finish the request with a JSON response."""
+        return self.finish(kwargs)
 
     def write_error(self, status_code: int, **kwargs: dict[str, Any]) -> None:
         """Finish with the status code and the reason as dict."""
-        self.finish(
-            {
-                "status": status_code,
-                "reason": self.get_error_message(**kwargs),
-            }
+        self.finish_dict(
+            status=status_code,
+            reason=self.get_error_message(**kwargs),
         )
 
 
@@ -872,7 +857,6 @@ class NotFoundHandler(HTMLRequestHandler):
         if new_path.lower() in {
             "/-profiler/phpinfo",
             "/.aws/credentials",
-            "/.env",
             "/.env.bak",
             "/.ftpconfig",
             "/admin/controller/extension/extension",
@@ -960,51 +944,3 @@ class ZeroDivision(HTMLRequestHandler):
         """Divide by zero and raise an error."""
         if not self.request.method == "OPTIONS":
             420 / 0  # pylint: disable=pointless-statement
-
-
-class ElasticRUM(BaseRequestHandler):
-    """A request handler that serves the RUM script."""
-
-    URL = (
-        "https://unpkg.com/@elastic/apm-rum@{}"
-        "/dist/bundles/elastic-apm-rum.umd{}.js{}"
-    )
-    SCRIPTS: dict[str, tuple[str, float]] = {}
-    CACHE_TIME = 365 * 60 * 60 * 24
-
-    async def get(self, version: str, spam: str = "", eggs: str = "") -> None:
-        """Serve the RUM script."""
-        key = version + spam + eggs
-        if key not in self.SCRIPTS or self.SCRIPTS[key][1] < time.monotonic():
-            response = await AsyncHTTPClient().fetch(
-                self.URL.format(version, spam, eggs),
-                raise_error=False,
-                ca_certs=os.path.join(ROOT_DIR, "ca-bundle.crt"),
-            )
-            if response.code != 200:
-                raise HTTPError(response.code, reason=response.reason)
-            self.SCRIPTS[key] = (
-                response.body.decode(),
-                time.monotonic() + 365 * 60 * 60 * 24,
-            )
-            new_path = urlsplit(response.effective_url).path
-            if new_path.endswith(".js"):
-                BaseRequestHandler.ELASTIC_RUM_JS_URL = new_path
-            logger.info("RUM script %s updated", new_path)
-            self.redirect(self.fix_url(new_path), False)
-            return
-        if eggs:
-            self.set_header("Content-Type", "application/json; charset=UTF-8")
-        else:
-            self.set_header(
-                "Content-Type", "application/javascript; charset=UTF-8"
-            )
-            if spam:
-                self.set_header("SourceMap", self.URL + ".map")
-        self.set_header(
-            "Expires", datetime.utcnow() + timedelta(seconds=self.CACHE_TIME)
-        )
-        self.set_header(
-            "Cache-Control", f"public, min-fresh={self.CACHE_TIME}, immutable"
-        )
-        return await self.finish(self.SCRIPTS[key][0])
