@@ -57,7 +57,11 @@ FILE_HASHES_DICT: dict[str, str] = create_file_hashes_dict()
 def get_handlers() -> list[Handler]:
     """Return a list of handlers for static files."""
     handlers: list[Handler] = [
-        (r"/(robots.txt|favicon.ico)", StaticFileHandler, {"path": STATIC_DIR})
+        (
+            r"/(robots\.txt|favicon\.ico|\.env)",
+            StaticFileHandler,
+            {"path": STATIC_DIR},
+        )
     ]
     if sys.flags.dev_mode:
         # add handlers for the not minified CSS files
@@ -122,6 +126,9 @@ class CachedStaticFileHandler(StaticFileHandler):
     def set_headers(self) -> None:
         """Set the default headers for this handler."""
         super().set_headers()
+        if self.settings.get("HSTS"):
+            # dev.mozilla.org/docs/Web/HTTP/Headers/Strict-Transport-Security
+            self.set_header("Strict-Transport-Security", "max-age=63072000")
         if not sys.flags.dev_mode and "v" in self.request.arguments:
             self.set_header(  # never changes
                 "Cache-Control",
