@@ -1,11 +1,11 @@
-// @license magnet:?xt=urn:btih:0b31508aeb0634b347b8270c7bee4d411b5d4109&dn=agpl-3.0.txt AGPL-3.0
+// @license magnet:?xt=urn:btih:0b31508aeb0634b347b8270c7bee4d411b5d4109&dn=agpl-3.0.txt GNU-AGPL-3.0-or-later
 const w = window;
 const d = document;
 const elById = (id) => d.getElementById(id);
 const log = console.log;
 const error = console.error;
 
-w.lastLocation = w.location;
+w.lastLocation = String(w.location);
 
 function post(
     url,
@@ -60,24 +60,53 @@ function setURLParam(
     const newUrl = `${w.location.origin}${w.location.pathname}?${urlParams.toString()}`;
     //log("newUrl", newUrl);
     state["stateType"] = stateType;
-    if (push && newUrl !== w.location) {
+    if (push && newUrl !== w.location.href) {
         history.pushState(state, newUrl, newUrl);
     } else {
         history.replaceState(state, newUrl, newUrl)
     }
+    w.lastLocation = w.location.href;
     return newUrl;
 }
 
+function scrollToId() {
+    if (w.location.hash === "") return;
+    const el = d.querySelector(w.location.hash);
+    if (!el) return;
+    w.scrollBy(
+        0,
+        el.getBoundingClientRect().top - Math.floor(
+            parseFloat(getComputedStyle(elById("header")).height)
+        )
+    );
+}
+// scroll after few ms so the scroll is right on page load
+setTimeout(scrollToId, 4);
+w.onhashchange = scrollToId;
+
 w.onpopstate = (event) => {
-    if (event.state
+    if (
+        w.lastLocation.split("#")[0]
+        === w.location.href.split("#")[0]
+    ) {
+        // Only hash changed
+        w.lastLocation = w.location.href;
+        scrollToId();
+        return;
+    }
+    if (
+        event.state
         && event.state["stateType"]
         && w.PopStateHandlers[event.state["stateType"]]
     ) {
         w.PopStateHandlers[event.state["stateType"]](event);
-        w.lastLocation = w.location;
+        w.lastLocation = w.location.href;
+        event.preventDefault();
+        scrollToId();
         return;
     }
     error("Couldn't handle state. ", event.state);
+    w.lastLocation = w.location.href;
     w.location.reload();
 }
 
