@@ -20,7 +20,7 @@ import os
 import random
 import re
 import time
-from collections.abc import Callable
+from collections.abc import Callable, Sequence
 from dataclasses import dataclass, field
 from datetime import datetime
 from enum import IntFlag
@@ -60,7 +60,7 @@ class PageInfo:
     hidden: bool = False  # whether to hide this page info on the page
     short_name: None | str = None  # short name for the page
 
-    def search(self, query: str | list[str]) -> float:  # noqa: C901
+    def search(self, query: str | Sequence[str]) -> float:  # noqa: C901
         # pylint: disable=too-complex
         """
         Check whether this should be shown on the search page.
@@ -72,6 +72,7 @@ class PageInfo:
             return 0
 
         score: float = 0
+        words: Sequence[str]
 
         if isinstance(query, str):
             words = re.split(r"\s+", query)
@@ -141,7 +142,7 @@ class ModuleInfo(PageInfo):
 
         return ", ".join(self.keywords)
 
-    def search(self, query: str | list[str]) -> float:
+    def search(self, query: str | Sequence[str]) -> float:
         score = super().search(query)
 
         if len(self.sub_pages) > 0:
@@ -231,6 +232,7 @@ def add_args_to_url(url: str | SplitResult, **kwargs: dict[str, Any]) -> str:
 
 def anonymize_ip(address: str, *, ignore_invalid: bool = False) -> str:
     """Anonymize an IP address."""
+    address = address.strip()
     try:
         version = ip_address(address).version
     except ValueError:
@@ -262,15 +264,10 @@ def apm_anonymization_processor(  # pylint: disable=unused-argument
         if "headers" in request:
             headers = request["headers"]
             if "X-Forwarded-For" in headers:
-                if "," in headers["X-Forwarded-For"]:
-                    headers["X-Forwarded-For"] = anonymize_ip(
-                        headers["X-Forwarded-For"].split(","),
-                        ignore_invalid=True,
-                    )
-                else:
-                    headers["X-Forwarded-For"] = anonymize_ip(
-                        headers["X-Forwarded-For"], ignore_invalid=True
-                    )
+                headers["X-Forwarded-For"] = ", ".join(
+                    anonymize_ip(_, ignore_invalid=True)
+                    for _ in headers["X-Forwarded-For"].split(",")
+                )
             for header in headers:
                 if "ip" in header.lower().split("-"):
                     headers[header] = anonymize_ip(
@@ -378,9 +375,8 @@ async def geoip(
 def get_themes() -> tuple[str, ...]:
     """Get a list of available themes."""
     files = os.listdir(os.path.join(STATIC_DIR, "style/themes"))
-
     return (
-        *(file[:-4] for file in files if file.endswith(".css")),
+        *(file.removesuffix(".css") for file in files if file.endswith(".css")),
         "random",  # add random to the list of themes
         "random-dark",
     )
@@ -410,11 +406,10 @@ def n_from_set(_set: set[T] | frozenset[T], _n: int) -> set[T]:
     i = 0
     new_set = set()
     for _el in _set:
-        if i < _n:
-            i += 1
-            new_set.add(_el)
-        else:
+        if i >= _n:
             break
+        i += 1
+        new_set.add(_el)
     return new_set
 
 
@@ -467,7 +462,6 @@ async def run(
         stderr=stderr,
         **kwargs,
     )
-
     output = await proc.communicate()
     return proc.returncode, *output
 
